@@ -182,7 +182,9 @@ usage(FILE *out, const char *name)
           " -T, --no-touch        ignore touch events.\n"
           " -K, --no-keyboard     ignore keyboard events.\n"
           " --binding             use alternative key bindings. Available options: vim\n"
+          " --fixed-height        prevent the display from changing height on filter.\n"
           " --scrollbar           display scrollbar. (none (default), always, autohide)\n"
+          " --counter             display a matched/total items counter. (none (default), always)\n"
           " --accept-single       immediately return if there is only one item.\n"
           " --ifne                only display menu if there are items.\n"
           " --fork                always fork. (bemenu-run)\n"
@@ -208,6 +210,7 @@ usage(FILE *out, const char *name)
           " -M, --margin          defines the empty space on either side of the menu. (wx)\n"
           " -W, --width-factor    defines the relative width factor of the menu (from 0 to 1). (wx)\n"
           " -B, --border          defines the width of the border in pixels around the menu. (wx)\n"
+          " -R  --border-radius   defines the radius of the border around the menu (0 = no curved borders).\n"
           " --ch                  defines the height of the cursor (0 = scales with line height). (wx)\n"
           " --cw                  defines the width of the cursor. (wx)\n"
           " --hp                  defines the horizontal padding for the entries in single line mode. (wx)\n"
@@ -269,7 +272,9 @@ do_getopt(struct client *client, int *argc, char **argv[])
         { "index",        required_argument, 0, 'I' },
         { "prefix",       required_argument, 0, 'P' },
         { "password",     no_argument,       0, 'x' },
+        { "fixed-height", no_argument,       0, 0x090 },
         { "scrollbar",    required_argument, 0, 0x100 },
+        { "counter",      required_argument, 0, 0x10a },
         { "accept-single",no_argument,       0, 0x11a },
         { "ifne",         no_argument,       0, 0x117 },
         { "fork",         no_argument,       0, 0x118 },
@@ -286,6 +291,7 @@ do_getopt(struct client *client, int *argc, char **argv[])
         { "margin",       required_argument, 0, 'M' },
         { "width-factor", required_argument, 0, 'W' },
         { "border",       required_argument, 0, 'B' },
+        { "border-radius",required_argument, 0, 'R' },
         { "ch",           required_argument, 0, 0x120 },
         { "cw",           required_argument, 0, 0x125 },
         { "hp",           required_argument, 0, 0x122 },
@@ -322,7 +328,7 @@ do_getopt(struct client *client, int *argc, char **argv[])
     for (optind = 0;;) {
         int32_t opt;
 
-        if ((opt = getopt_long(*argc, *argv, "hviwxcl:I:p:P:I:bfF:m:H:M:W:B:nsCTK", opts, NULL)) < 0)
+        if ((opt = getopt_long(*argc, *argv, "hviwxcl:I:p:P:I:bfF:m:H:M:W:B:R:nsCTK", opts, NULL)) < 0)
             break;
 
         switch (opt) {
@@ -357,9 +363,15 @@ do_getopt(struct client *client, int *argc, char **argv[])
             case 'I':
                 client->selected = strtol(optarg, NULL, 10);
                 break;
+            case 0x090:
+                client->fixed_height = true;
+                break;
             case 0x100:
                 client->scrollbar = (!strcmp(optarg, "none") ? BM_SCROLLBAR_NONE : (!strcmp(optarg, "always") ? BM_SCROLLBAR_ALWAYS : (!strcmp(optarg, "autohide") ? BM_SCROLLBAR_AUTOHIDE : BM_SCROLLBAR_NONE)));
                 break;
+            case 0x10a:
+                client->counter = (!strcmp(optarg, "always"));
+                break;
             case 0x11a:
                 client->accept_single = true;
                 break;
@@ -412,6 +424,9 @@ do_getopt(struct client *client, int *argc, char **argv[])
             case 'B':
                 client->border_size = strtol(optarg, NULL, 10);
                 break;
+            case 'R':
+                client->border_radius = strtol(optarg, NULL, 10);
+                break;
             case 0x120:
                 client->cursor_height = strtol(optarg, NULL, 10);
                 break;
@@ -537,12 +552,15 @@ menu_with_options(struct client *client)
     bm_menu_set_wrap(menu, client->wrap);
     bm_menu_set_monitor(menu, client->monitor);
     bm_menu_set_monitor_name(menu, client->monitor_name);
+    bm_menu_set_fixed_height(menu, client->fixed_height);
     bm_menu_set_scrollbar(menu, client->scrollbar);
+    bm_menu_set_counter(menu, client->counter);
     bm_menu_set_panel_overlap(menu, !client->no_overlap);
     bm_menu_set_spacing(menu, !client->no_spacing);
     bm_menu_set_password(menu, client->password);
     bm_menu_set_width(menu, client->hmargin_size, client->width_factor);
     bm_menu_set_border_size(menu, client->border_size);
+    bm_menu_set_border_radius(menu, client->border_radius);
     bm_menu_set_key_binding(menu, client->key_binding);
 
     if (client->center) {
@@ -590,8 +608,8 @@ run_menu(const struct client *client, struct bm_menu *menu, void (*item_cb)(cons
 
     uint32_t unicode;
     enum bm_key key = BM_KEY_NONE;
-    struct bm_pointer pointer;
-    struct bm_touch touch;
+    struct bm_pointer pointer = {0};
+    struct bm_touch touch = {0};
     enum bm_run_result status = BM_RUN_RESULT_RUNNING;
     do {
         if (!bm_menu_render(menu)) {
