@@ -21,11 +21,14 @@ struct client {
     uint32_t monitor;
     uint32_t hmargin_size;
     uint32_t border_size;
+    uint32_t border_radius;
     float width_factor;
     bool bottom;
     bool center;
     bool grab;
     bool wrap;
+    bool fixed_height; 
+    bool counter;
     bool accept_single;
     bool ifne;
     bool no_overlap;
