@@ -644,6 +644,24 @@ BM_PUBLIC void bm_menu_set_border_size(struct bm_menu* menu, uint32_t border_siz
 
 BM_PUBLIC uint32_t bm_menu_get_border_size(struct bm_menu* menu);
 
+/**
+ * Set the radius of the border for the bar
+ *
+ * @param menu bm_menu to get border radius from.
+ * @return border radius of the menu.
+ */
+
+BM_PUBLIC void bm_menu_set_border_radius(struct bm_menu* menu, uint32_t border_radius);
+
+/**
+ * Get the size of the border for the bar
+ *
+ * @param menu bm_menu to get border radius from.
+ * @return border radius of the menu.
+ */
+
+BM_PUBLIC uint32_t bm_menu_get_border_radius(struct bm_menu* menu);
+
 /**
  * Set a hexadecimal color for element.
  *
@@ -671,6 +689,24 @@ BM_PUBLIC const char* bm_menu_get_color(const struct bm_menu *menu, enum bm_colo
  */
 BM_PUBLIC void bm_menu_set_scrollbar(struct bm_menu *menu, enum bm_scrollbar_mode mode);
 
+/**
+ * Set fixed height mode of the bar.
+ *
+ * @param menu bm_menu to set the fixed height for.
+ * @param mode to be set.
+ */
+
+BM_PUBLIC void bm_menu_set_fixed_height(struct bm_menu *menu, bool mode);
+
+/**
+ * Get the fixed height mode of the bar.
+ *
+ * @param menu bm_menu to get the fixed height from.
+ * @return current fixed height mode
+ */
+
+BM_PUBLIC bool bm_menu_get_fixed_height(struct bm_menu *menu);
+
 /**
  * Return current scrollbar display mode.
  *
@@ -679,6 +715,24 @@ BM_PUBLIC void bm_menu_set_scrollbar(struct bm_menu *menu, enum bm_scrollbar_mod
  */
 BM_PUBLIC enum bm_scrollbar_mode bm_menu_get_scrollbar(struct bm_menu *menu);
 
+/**
+ * Set the counter display mode.
+ *
+ * @param menu bm_menu to set the counter for.
+ * @param display mode to be set.
+ */
+
+BM_PUBLIC void bm_menu_set_counter(struct bm_menu *menu, bool mode);
+
+/**
+ * Get the counter display mode.
+ *
+ * @param menu bm_menu to get the counter from.
+ * @return current counter display mode
+ */
+
+BM_PUBLIC bool bm_menu_get_counter(struct bm_menu *menu);
+
 /**
  * Set the vertical alignment of the bar.
  *
