@@ -352,11 +352,21 @@ struct bm_menu {
      */
     enum bm_filter_mode filter_mode;
 
+    /**
+     * Current fixed height mode.
+     */
+    bool fixed_height;
+
     /**
      * Current Scrollbar display mode.
      */
     enum bm_scrollbar_mode scrollbar;
 
+    /**
+     * Current counter display mode.
+     */
+    bool counter;
+
     /**
      * Should selection be wrapped?
      */
@@ -382,6 +392,11 @@ struct bm_menu {
      */
     uint32_t border_size;
 
+    /**
+     * Border radius
+     */
+    uint32_t border_radius;
+
     /**
      * Is menu grabbed?
      */
