@@ -360,6 +360,20 @@ bm_menu_get_border_size(struct bm_menu* menu)
     return menu->border_size;
 }
 
+void
+bm_menu_set_border_radius(struct bm_menu* menu, uint32_t border_radius)
+{
+    assert(menu);
+    menu->border_radius = border_radius;
+}
+
+uint32_t
+bm_menu_get_border_radius(struct bm_menu* menu)
+{
+    assert(menu);
+    return menu->border_radius;
+}
+
 uint32_t
 bm_menu_get_height(struct bm_menu *menu)
 {
@@ -420,6 +434,18 @@ char* bm_menu_get_color(const struct bm_menu *menu, enum bm_color color)
     return menu->colors[color].hex;
 }
 
+void
+bm_menu_set_fixed_height(struct bm_menu *menu, bool mode)
+{
+    menu->fixed_height = mode;
+}
+
+bool
+bm_menu_get_fixed_height(struct bm_menu *menu)
+{
+    return menu->fixed_height;
+}
+
 void
 bm_menu_set_scrollbar(struct bm_menu *menu, enum bm_scrollbar_mode mode)
 {
@@ -432,6 +458,18 @@ bm_menu_get_scrollbar(struct bm_menu *menu)
     return menu->scrollbar;
 }
 
+void
+bm_menu_set_counter(struct bm_menu *menu, bool mode)
+{
+    menu->counter = mode;
+}
+
+bool
+bm_menu_get_counter(struct bm_menu *menu)
+{
+    return menu->counter;
+}
+
 void
 bm_menu_set_align(struct bm_menu *menu, enum bm_align align)
 {
@@ -639,7 +677,7 @@ bm_menu_set_highlighted_index(struct bm_menu *menu, uint32_t index)
     bm_menu_get_filtered_items(menu, &count);
 
     if (count <= index)
-        return 0;
+        index = (count > 0 ? count - 1 : 0);
 
     if (menu->index != index)
         menu->dirty = true;
@@ -764,7 +802,6 @@ bm_menu_filter(struct bm_menu *menu)
         size_t oldLen = strlen(menu->old_filter);
         addition = (oldLen < len && !memcmp(menu->old_filter, menu->filter, oldLen));
     }
-
     if (menu->old_filter && addition && menu->filtered.count <= 0)
         return;
 
@@ -865,13 +902,14 @@ menu_point_select(struct bm_menu *menu, uint32_t posx, uint32_t posy, uint32_t d
     }
     uint32_t selected_line = posy / line_height;
 
-    if (0 == selected_line) { // Mouse over title bar
-        return;
-    }
-
     assert(menu->lines != 0);
     uint16_t current_page_index = menu->index / menu->lines;
 
+    if (0 == selected_line) { // Mouse over title bar
+        bm_menu_set_highlighted_index(menu, current_page_index * menu->lines);
+        return;
+    }
+
     if (selected_line >= displayed) { // This might be useless
         return;
     }
