@@ -257,6 +257,18 @@ bm_cairo_entry_message(char *entry_text, bool highlighted, uint32_t event_feedba
     }
 }
 
+static inline void
+bm_cairo_draw_rounded_path(cairo_t *cr, double x, double y, double width, double height, double radius)
+{
+    double degrees = M_PI / 180;
+    cairo_new_sub_path(cr);
+    cairo_arc(cr, x + width - radius, y + radius, radius, -90 * degrees, 0 * degrees);
+    cairo_arc(cr, x + width - radius, y + height - radius, radius, 0 * degrees, 90 * degrees);
+    cairo_arc(cr, x + radius, y + height - radius, radius, 90 * degrees, 180 * degrees);
+    cairo_arc(cr, x + radius, y + radius, radius, 180 * degrees, 270 * degrees);
+    cairo_close_path(cr);
+}
+
 static inline void
 bm_cairo_paint(struct cairo *cairo, uint32_t width, uint32_t max_height, const struct bm_menu *menu, struct cairo_paint_result *out_result)
 {
@@ -282,6 +294,12 @@ bm_cairo_paint(struct cairo *cairo, uint32_t width, uint32_t max_height, const s
     uint32_t height = fmin(fmax(menu->line_height, ascii_height), max_height);
     uint32_t vpadding = (height - ascii_height)/2;
 
+    uint32_t border_radius = menu->border_radius;
+
+    uint32_t total_item_count = menu->items.count;
+    uint32_t filtered_item_count;
+    bm_menu_get_filtered_items(menu, &filtered_item_count);
+
     cairo_set_source_rgba(cairo->cr, 0, 0, 0, 0);
     cairo_rectangle(cairo->cr, 0, 0, width, height);
 
@@ -354,8 +372,16 @@ bm_cairo_paint(struct cairo *cairo, uint32_t width, uint32_t max_height, const s
 
         uint32_t posy = titleh;
         const uint32_t page = (menu->index / lines) * lines;
-        for (uint32_t l = 0, i = page; l < lines && i < count && posy < max_height; ++i, ++l) {
-            bool highlighted = (items[i] == bm_menu_get_highlighted_item(menu));
+        
+        for (uint32_t l = 0, i = page; l < lines && posy < max_height; ++i, ++l) {
+            if (!menu->fixed_height && i >= count) {
+                continue;
+            }
+
+            bool highlighted = false;
+            if (i < count) {
+                highlighted = (items[i] == bm_menu_get_highlighted_item(menu));
+            }
 
             if (highlighted) {
                 if (menu->event_feedback) {
@@ -365,18 +391,22 @@ bm_cairo_paint(struct cairo *cairo, uint32_t width, uint32_t max_height, const s
                     bm_cairo_color_from_menu_color(menu, BM_COLOR_HIGHLIGHTED_FG, &paint.fg);
                     bm_cairo_color_from_menu_color(menu, BM_COLOR_HIGHLIGHTED_BG, &paint.bg);
                 }
-            } else if (bm_menu_item_is_selected(menu, items[i])) {
+            } else if (i < count && bm_menu_item_is_selected(menu, items[i])) {
                 bm_cairo_color_from_menu_color(menu, BM_COLOR_SELECTED_FG, &paint.fg);
                 bm_cairo_color_from_menu_color(menu, BM_COLOR_SELECTED_BG, &paint.bg);
-            } else if (i % 2 == 1) {
+            } else if (i < count && i % 2 == 1) {
                 bm_cairo_color_from_menu_color(menu, BM_COLOR_ALTERNATE_FG, &paint.fg);
                 bm_cairo_color_from_menu_color(menu, BM_COLOR_ALTERNATE_BG, &paint.bg);
             } else {
                 bm_cairo_color_from_menu_color(menu, BM_COLOR_ITEM_FG, &paint.fg);
                 bm_cairo_color_from_menu_color(menu, BM_COLOR_ITEM_BG, &paint.bg);
             }
+            
+            char *line_str = "";
+            if (i < count) {
+                line_str = bm_cairo_entry_message(items[i]->text, highlighted, menu->event_feedback, i,  count);
+            }
 
-            char *line_str = bm_cairo_entry_message(items[i]->text, highlighted, menu->event_feedback, i,  count);
             if (menu->prefix && highlighted) {
                 paint.pos = (struct pos){ spacing_x + border_size, posy+vpadding + border_size };
                 paint.box = (struct box){ 4, 0, vpadding, -vpadding, width - paint.pos.x, height };
@@ -455,21 +485,34 @@ bm_cairo_paint(struct cairo *cairo, uint32_t width, uint32_t max_height, const s
             out_result->displayed += (cl < width);
             out_result->height = fmax(out_result->height, result.height);
         }
-
+        bm_cairo_color_from_menu_color(menu, BM_COLOR_FILTER_FG, &paint.fg);
+        bm_cairo_color_from_menu_color(menu, BM_COLOR_FILTER_BG, &paint.bg);
         if (menu->wrap || menu->index + 1 < count) {
-            bm_cairo_color_from_menu_color(menu, BM_COLOR_FILTER_FG, &paint.fg);
-            bm_cairo_color_from_menu_color(menu, BM_COLOR_FILTER_BG, &paint.bg);
             bm_pango_get_text_extents(cairo, &paint, &result, ">");
             paint.pos = (struct pos){ width/cairo->scale - result.x_advance - 2, vpadding + border_size };
             paint.box = (struct box){ 1, 2, vpadding, -vpadding, 0, height };
             bm_cairo_draw_line(cairo, &paint, &result, ">");
         }
+        
+    }
+
+    if (menu->counter) {
+        char counter[128];
+        snprintf(counter, sizeof(counter), "[%u/%u]", filtered_item_count, total_item_count);
+        bm_pango_get_text_extents(cairo, &paint, &result, "%s", counter);
+        paint.pos = (struct pos){ width/cairo->scale - result.x_advance - 10, vpadding + border_size };
+        paint.box = (struct box){ 1, 2, vpadding, -vpadding, 0, height };
+        bm_cairo_draw_line(cairo, &paint, &result, "%s", counter);
     }
 
     // Draw borders
     bm_cairo_color_from_menu_color(menu, BM_COLOR_BORDER, &paint.fg);
     cairo_set_source_rgba(cairo->cr, paint.fg.r, paint.fg.b, paint.fg.g, paint.fg.a);
-    cairo_rectangle(cairo->cr, 0, 0, width + border_size, (height * (page_length + 1)) + (2 * border_size));
+    if (!border_radius) {
+        cairo_rectangle(cairo->cr, 0, 0, (width + border_size)/cairo->scale, (height * (page_length + 1)) + (2 * border_size));
+    } else {
+        bm_cairo_draw_rounded_path(cairo->cr, 0, 0, (width + border_size)/cairo->scale, (height * (page_length + 1)) + (2 * border_size), border_radius);
+    }
     cairo_set_line_width(cairo->cr, 2 * menu->border_size);
     cairo_stroke(cairo->cr);
 
